Crate fart_2d_geom

Crate fart_2d_geom 

Two-dimensional geometry algorithms built on top of euclid.

Structs

ConvexPolygon
A convex polygon.
Line
A line between two points.
Polygon
A polygon.

Enums

LineIntersection
The result of Line::intersection providing the intersection point between two line segments, if any.
RelativeDirection
The direction a point lies relative to a line. Returned by Line::relative_direction_of.

Functions

center
Find the center (mean) of a set of points.
is_counter_clockwise
Are the given vertices in counter-clockwise order?
line
Convenience function for creating lines.
sort_around
Sort the given points around the given pivot point in counter-clockwise order, starting from 12 o’clock.