LineIntersection

Enum LineIntersection 

pub enum LineIntersection<U> {
    None,
    Proper(Point2D<f64, U>),
    Improper(Point2D<f64, U>),
    Collinear(Point2D<f64, U>),
}
The result of Line::intersection providing the intersection point between two line segments, if any.

Variants



None

The line segments do not intersect.



Proper(Point2D<f64, U>)

The line segments properly intersect at the given point, and are not collinear.



Improper(Point2D<f64, U>)

The line segments improperly intersect and are not collinear, with the endpoint of one line segment landing on the other.



Collinear(Point2D<f64, U>)

The lines are collinear and intersect at the given point (and perhaps infinitely many other points as well).

Implementations

Source

impl<U> LineIntersection<U>

pub fn is_none(&self) -> bool

Is this a LineIntersection::None?

pub fn is_proper(&self) -> bool

Is this a LineIntersection::Proper?

pub fn is_improper(&self) -> bool

Is this a LineIntersection::Improper?

pub fn is_collinear(&self) -> bool

Is this a LineIntersection::Collinear?

pub fn point(&self) -> Option<Point2D<f64, U>>

Get the intersection point, if any, regardless if this is a proper, improper, or collinear intersection.