pub enum LineIntersection<U> {
None,
Proper(Point2D<f64, U>),
Improper(Point2D<f64, U>),
Collinear(Point2D<f64, U>),
}Expand description
The result of Line::intersection providing the intersection point between
two line segments, if any.
Variants
None
The line segments do not intersect.
Proper(Point2D<f64, U>)
The line segments properly intersect at the given point, and are not collinear.
Improper(Point2D<f64, U>)
The line segments improperly intersect and are not collinear, with the endpoint of one line segment landing on the other.
Collinear(Point2D<f64, U>)
The lines are collinear and intersect at the given point (and perhaps infinitely many other points as well).
Implementations
Sourceimpl<U> LineIntersection<U>
impl<U> LineIntersection<U>
Sourcepub fn is_improper(&self) -> bool
pub fn is_improper(&self) -> bool
Is this a LineIntersection::Improper?
Sourcepub fn is_collinear(&self) -> bool
pub fn is_collinear(&self) -> bool
Is this a LineIntersection::Collinear?